@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     SPDX-FileCopyrightText: 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel.org>
+    SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -32,7 +32,7 @@ public:
     ~MessagingWidget() override;
 
     void updateAddRemoveButton(bool addButtonEnabled);
-    KContacts::Impp imAddress() const;
+    [[nodiscard]] KContacts::Impp imAddress() const;
     void setIMAddress(const KContacts::Impp &address);
     void setPreferred(bool b);
     void clearWidget();
